@@ -9,15 +9,18 @@ class CloudStorageAuthenticate : public QObject {
 	Q_OBJECT
 public:
 	QNetworkReply* backend(const QString& email,const QString& password,const QString& pin = QString(),const QString& newpasswd = QString());
+	QNetworkReply* deleteAccount(const QString& email, const QString &passwd);
 	explicit CloudStorageAuthenticate(QObject *parent);
 signals:
 	void finishedAuthenticate();
+	void finishedDelete();
 	void passwordChangeSuccessful();
 private
 slots:
 	void uploadError(QNetworkReply::NetworkError error);
 	void sslErrors(const QList<QSslError> &errorList);
 	void uploadFinished();
+	void deleteFinished();
 private:
 	QNetworkReply *reply;
 	QString userAgent;
