@@ -795,7 +795,7 @@ pressure_t calculate_surface_pressure(const struct dive *dive)
 	pressure_t res;
 	int sum = 0, nr = 0;
 
-	for_each_dc (dive, dc) {
+	for_each_relevant_dc(dive, dc) {
 		if (dc->surface_pressure.mbar) {
 			sum += dc->surface_pressure.mbar;
 			nr++;
@@ -826,7 +826,7 @@ static void fixup_water_salinity(struct dive *dive)
 	struct divecomputer *dc;
 	int sum = 0, nr = 0;
 
-	for_each_dc (dive, dc) {
+	for_each_relevant_dc (dive, dc) {
 		if (dc->salinity) {
 			if (dc->salinity < 500)
 				dc->salinity += FRESHWATER_SALINITY;
@@ -848,12 +848,13 @@ static void fixup_meandepth(struct dive *dive)
 	struct divecomputer *dc;
 	int sum = 0, nr = 0;
 
-	for_each_dc (dive, dc) {
+	for_each_relevant_dc (dive, dc) {
 		if (dc->meandepth.mm) {
 			sum += dc->meandepth.mm;
 			nr++;
 		}
 	}
+
 	if (nr)
 		dive->meandepth.mm = (sum + nr / 2) / nr;
 }
@@ -863,9 +864,9 @@ static void fixup_duration(struct dive *dive)
 	struct divecomputer *dc;
 	duration_t duration = { };
 
-	for_each_dc (dive, dc)
+	for_each_relevant_dc (dive, dc) {
 		duration.seconds = MAX(duration.seconds, dc->duration.seconds);
-
+	}
 	dive->duration.seconds = duration.seconds;
 }
 
@@ -981,8 +982,9 @@ static void fixup_dc_depths(struct dive *dive, struct divecomputer *dc)
 	}
 
 	update_depth(&dc->maxdepth, maxdepth);
-	if (maxdepth > dive->maxdepth.mm)
-		dive->maxdepth.mm = maxdepth;
+	if (!has_planned(dive, false) || !is_dc_planner(dc))
+		if (maxdepth > dive->maxdepth.mm)
+			dive->maxdepth.mm = maxdepth;
 }
 
 static void fixup_dc_ndl(struct divecomputer *dc)
@@ -1208,17 +1210,41 @@ static void fixup_no_o2sensors(struct divecomputer *dc)
 	}
 }
 
-static void fixup_dc_sample_sensors(struct divecomputer *dc, int nr_cylinders)
+static void fixup_dc_sample_sensors(struct dive *dive, struct divecomputer *dc)
 {
+	unsigned long sensor_mask = 0;
+
 	for (int i = 0; i < dc->samples; i++) {
 		struct sample *s = dc->sample + i;
 		for (int j = 0; j < MAX_SENSORS; j++) {
-			if (s->sensor[j] < 0 || s->sensor[j] >= nr_cylinders) {
+			int sensor = s->sensor[j];
+
+			// No invalid sensor ID's, please
+			if (sensor < 0 || sensor > MAX_SENSORS) {
 				s->sensor[j] = NO_SENSOR;
 				s->pressure[j].mbar = 0;
+				continue;
 			}
+
+			// Don't bother tracking sensors with no data
+			if (!s->pressure[j].mbar) {
+				s->sensor[j] = NO_SENSOR;
+				continue;
+			}
+
+			// Remember the set of sensors we had
+			sensor_mask |= 1ul << sensor;
 		}
 	}
+
+	// Ignore the sensors we have cylinders for
+	sensor_mask >>= dive->cylinders.nr;
+
+	// Do we need to add empty cylinders?
+	while (sensor_mask) {
+		add_empty_cylinder(&dive->cylinders);
+		sensor_mask >>= 1;
+	}
 }
 
 static void fixup_dive_dc(struct dive *dive, struct divecomputer *dc)
@@ -1238,12 +1264,12 @@ static void fixup_dive_dc(struct dive *dive, struct divecomputer *dc)
 	/* Fix up gas switch events */
 	fixup_dc_gasswitch(dive, dc);
 
+	/* Fix up cylinder ids in pressure sensors */
+	fixup_dc_sample_sensors(dive, dc);
+
 	/* Fix up cylinder pressures based on DC info */
 	fixup_dive_pressures(dive, dc);
 
-	/* Fix up cylinder ids in pressure sensors */
-	fixup_dc_sample_sensors(dc, dive->cylinders.nr);
-
 	fixup_dc_events(dc);
 
 	/* Fixup CCR / PSCR dives with o2sensor values, but without no_o2sensors */
@@ -2961,7 +2987,7 @@ static inline int dive_totaltime(const struct dive *dive)
 	int time =  dive->duration.seconds;
 	const struct divecomputer *dc;
 
-	for_each_dc(dive, dc) {
+	for_each_relevant_dc(dive, dc) {
 		int dc_time = dc_totaltime(dc);
 		if (dc_time > time)
 			time = dc_time;
@@ -3118,6 +3144,7 @@ struct dive *clone_delete_divecomputer(const struct dive *d, int dc_number)
 	res->id = dive_getUniqID();
 
 	delete_divecomputer(res, dc_number);
+	force_fixup_dive(res);
 
 	return res;
 }
