@@ -39,8 +39,11 @@ class DiveFilter {
 public:
 	static DiveFilter *instance();
 
+	void reset();
 	QString shownText() const;
+	int shownDives() const;
 	bool diveSiteMode() const; // returns true if we're filtering on dive site (on mobile always returns false)
+	std::vector<dive *> visibleDives() const;
 #ifndef SUBSURFACE_MOBILE
 	const QVector<dive_site *> &filteredDiveSites() const;
 	void startFilterDiveSites(QVector<dive_site *> ds);
@@ -50,12 +53,16 @@ public:
 	void setFilter(const FilterData &data);
 	ShownChange update(const QVector<dive *> &dives) const; // Update filter status of given dives and return dives whose status changed
 	ShownChange updateAll() const; // Update filter status of all dives and return dives whose status changed
+	void diveRemoved(const dive *dive) const; // Dive was removed; update count accordingly
 private:
 	DiveFilter();
 	bool showDive(const struct dive *d) const; // Should that dive be shown?
+	bool setFilterStatus(struct dive *d, bool shown) const;
+	void updateDiveStatus(dive *d, bool newStatus, ShownChange &change) const;
 
 	QVector<dive_site *> dive_sites;
 	FilterData filterData;
+	mutable int shown_dives;
 
 	// We use ref-counting for the dive site mode. The reason is that when switching
 	// between two tabs that both need dive site mode, the following course of
