@@ -5,9 +5,12 @@
 #endif
 
 #include "ssrf.h"
+#include "dive.h"
 #include "divesite.h"
-#include "subsurface-string.h"
+#include "gas.h"
 #include "parse.h"
+#include "sample.h"
+#include "subsurface-string.h"
 #include "divelist.h"
 #include "device.h"
 #include "membuffer.h"
@@ -217,7 +220,8 @@ static int cobalt_dive(void *param, int columns, char **data, char **column)
 
 
 int parse_cobalt_buffer(sqlite3 *handle, const char *url, const char *buffer, int size,
-			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+			    struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites,
+			    struct device_table *devices)
 {
 	UNUSED(buffer);
 	UNUSED(size);
@@ -229,6 +233,7 @@ int parse_cobalt_buffer(sqlite3 *handle, const char *url, const char *buffer, in
 	state.target_table = table;
 	state.trips = trips;
 	state.sites = sites;
+	state.devices = devices;
 	state.sql_handle = handle;
 
 	char get_dives[] = "select Id,strftime('%s',DiveStartTime),LocationId,'buddy','notes',Units,(MaxDepthPressure*10000/SurfacePressure)-10000,DiveMinutes,SurfacePressure,SerialNumber,'model' from Dive where IsViewDeleted = 0";
