@@ -296,7 +296,7 @@ static int divinglog_dive(void *param, int columns, char **data, char **column)
 		state->cur_dive->dc.duration.seconds = atoi(data[6]) * 60;
 
 	if (data[7])
-		utf8_string(data[7], &state->cur_dive->divemaster);
+		utf8_string(data[7], &state->cur_dive->diveguide);
 
 	if (data[8])
 		state->cur_dive->airtemp.mkelvin = C_to_mkelvin(atol(data[8]));
