@@ -15,6 +15,7 @@
 #include "gettext.h"
 #include "divesite.h"
 #include "sample.h"
+#include "subsurface-float.h"
 #include "subsurface-string.h"
 #include "device.h"
 #include "dive.h"
@@ -203,7 +204,7 @@ static int parse_gasmixes(device_data_t *devdata, struct dive *dive, dc_parser_t
 					report_error("gasmix %d for tank %d doesn't match", tank.gasmix, i);
 				}
 			}
-			if (!IS_FP_SAME(tank.volume, 0.0))
+			if (!nearly_0(tank.volume))
 				no_volume = false;
 
 			// this new API also gives us the beginning and end pressure for the tank
@@ -212,8 +213,8 @@ static int parse_gasmixes(device_data_t *devdata, struct dive *dive, dc_parser_t
 			// that matches the consumption and an end pressure of always 0
 			// In order to make this work, we arbitrary shift this up by 30bar so the
 			// rest of the code treats this as if they were valid values
-			if (!IS_FP_SAME(tank.beginpressure, 0.0)) {
-				if (!IS_FP_SAME(tank.endpressure, 0.0)) {
+			if (!nearly_0(tank.beginpressure)) {
+				if (!nearly_0(tank.endpressure)) {
 					cyl.start.mbar = lrint(tank.beginpressure * 1000);
 					cyl.end.mbar = lrint(tank.endpressure * 1000);
 				} else if (same_string(devdata->vendor, "Uwatec")) {
@@ -821,7 +822,7 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 		char *date_string = get_dive_date_c_string(dive->when);
 		dev_info(devdata, translate("gettextFromC", "Already downloaded dive at %s"), date_string);
 		free(date_string);
-		free(dive);
+		free_dive(dive);
 		return false;
 	}
 
@@ -844,7 +845,7 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 
 error_exit:
 	dc_parser_destroy(parser);
-	free(dive);
+	free_dive(dive);
 	return true;
 
 }
