@@ -644,7 +644,7 @@ static char *parse_sample_unit(struct sample *sample, double val, char *unit)
 /*
  * If the given cylinder doesn't exist, return NO_SENSOR.
  */
-static uint8_t sanitize_sensor_id(const struct dive *d, int nr)
+static int sanitize_sensor_id(const struct dive *d, int nr)
 {
 	return d && nr >= 0 && nr < d->cylinders.nr ? nr : NO_SENSOR;
 }
@@ -1365,6 +1365,22 @@ static unsigned parse_one_line(const char *buf, unsigned size, line_fn_t *fn, st
 	char line[MAXLINE + 1];
 	int off = 0;
 
+	// Check the first character of a line: an empty line
+	// or a line starting with a TAB is invalid, and likely
+	// due to an early string end quote due to a merge
+	// conflict. Ignore such a line.
+	switch (*p) {
+	case '\n': case '\t':
+		do {
+			if (*p++ == '\n')
+				break;
+		} while (p < end);
+		SSRF_INFO("git storage: Ignoring line '%.*s'", (int)(p-buf-1), buf);
+		return p - buf;
+	default:
+		break;
+	}
+
 	while (p < end) {
 		char c = *p++;
 		if (c == '\n')
