@@ -13,12 +13,6 @@
 #define UINT64_MAX (~0ULL)
 #endif
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-#define SKIP_EMPTY Qt::SkipEmptyParts
-#else
-#define SKIP_EMPTY QString::SkipEmptyParts
-#endif
-
 // The following functions fetch an arbitrary-length _unsigned_ integer from either
 // a file or a memory location in big-endian or little-endian mode. The size of the
 // integer is passed via a template argument [e.g. getBE<uint16_t>(...)].
