@@ -24,8 +24,9 @@
 #include "dive.h"
 #include "divesite.h"
 #include "errorhelper.h"
-#include "subsurface-string.h"
 #include "parse.h"
+#include "subsurface-float.h"
+#include "subsurface-string.h"
 #include "subsurface-time.h"
 #include "trip.h"
 #include "device.h"
@@ -161,7 +162,7 @@ static enum number_type parse_float(const char *buffer, double *res, const char
 	if (errno || *endp == buffer)
 		return NEITHER;
 	if (**endp == ',') {
-		if (IS_FP_SAME(val, rint(val))) {
+		if (nearly_equal(val, rint(val))) {
 			/* we really want to send an error if this is a Subsurface native file
 			 * as this is likely indication of a bug - but right now we don't have
 			 * that information available */
@@ -604,7 +605,7 @@ static void fahrenheit(char *buffer, temperature_t *temperature)
 
 	switch (integer_or_float(buffer, &val)) {
 	case FLOATVAL:
-		if (IS_FP_SAME(val.fp, 32.0))
+		if (nearly_equal(val.fp, 32.0))
 			break;
 		if (val.fp < 32.0)
 			temperature->mkelvin = C_to_mkelvin(val.fp);
@@ -1854,7 +1855,7 @@ int parse_dlf_buffer(unsigned char *buffer, size_t size, struct dive_table *tabl
 	// ptr[14] >> 1 is scrubber used in %
 
 	// 3 bit dive type
-	switch((ptr[15] & 0x30) >> 3) {
+	switch((ptr[15] & 0x38) >> 3) {
 	case 0: // unknown
 	case 1:
 		state.cur_dc->divemode = OC;
