@@ -21,6 +21,10 @@ extern struct dive *last_selected_dive(void);
 extern bool consecutive_selected(void);
 extern void select_newest_visible_dive();
 extern void select_single_dive(struct dive *d); // wrapper for setSelection() with a single dive. NULL clears the selection.
+extern void select_trip(struct dive_trip *trip);
+extern void deselect_trip(struct dive_trip *trip);
+extern struct dive_trip *single_selected_trip(); // returns trip if exactly one trip is selected, NULL otherwise.
+extern void clear_selection(void);
 
 #if DEBUG_SELECTION_TRACKING
 extern void dump_selection(void);
