@@ -2,7 +2,6 @@
 /* statistics.c
  *
  * core logic for the Info & Stats page -
- * char *get_minutes(int seconds);
  * void calculate_stats_summary(struct stats_summary *out, bool selected_only);
  * void calculate_stats_selected(stats_t *stats_selection);
  */
@@ -84,13 +83,6 @@ static void process_dive(struct dive *dive, stats_t *stats)
 	}
 }
 
-char *get_minutes(int seconds)
-{
-	static char buf[80];
-	snprintf(buf, sizeof(buf), "%d:%.2d", FRACTION(seconds, 60));
-	return buf;
-}
-
 /*
  * Calculate a summary of the statistics and put in the stats_summary
  * structure provided in the first parameter.
