@@ -277,6 +277,11 @@ QString formatDayOfWeek(int day)
 	}
 }
 
+QString formatMinutes(int seconds)
+{
+	return QString::asprintf("%d:%.2d", FRACTION(seconds, 60));
+}
+
 QString formatTripTitle(const dive_trip *trip)
 {
 	if (!trip)
