@@ -9,7 +9,7 @@
 extern "C" {
 #endif
 
-extern timestamp_t utc_mktime(struct tm *tm);
+extern timestamp_t utc_mktime(const struct tm *tm);
 extern void utc_mkdate(timestamp_t, struct tm *tm);
 extern int utc_year(timestamp_t timestamp);
 extern int utc_weekday(timestamp_t timestamp);
@@ -18,6 +18,8 @@ extern int utc_weekday(timestamp_t timestamp);
 extern timestamp_t parse_datetime(const char *s); /* returns 0 on error */
 extern char *format_datetime(timestamp_t timestamp); /* ownership of string passed to caller */
 
+extern const char *monthname(int mon);
+
 #ifdef __cplusplus
 }
 #endif
