@@ -13,7 +13,6 @@
 */
 
 #include <QTreeView>
-#include <QLineEdit>
 #include <QNetworkAccessManager>
 #include "qt-models/divetripmodel.h"
 #include "core/subsurface-qt/divelistnotifier.h"
@@ -63,7 +62,7 @@ private:
 	void mouseReleaseEvent(QMouseEvent *event) override;
 	void keyPressEvent(QKeyEvent *event) override;
 	void selectAll() override;
-	void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected);
+	void selectionChanged(const QItemSelection &selected, const QItemSelection &deselected) override;
 	void selectionChangeDone();
 	DiveTripModelBase::Layout currentLayout;
 	QModelIndex contextMenuIndex;
