@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "desktop-widgets/divesiteimportdialog.h"
 #include "commands/command.h"
-#include "core/display.h"
 #include "core/qthelper.h"
 #include "core/metrics.h"
 #include "core/subsurface-string.h"
@@ -16,8 +15,8 @@
 DivesiteImportDialog::DivesiteImportDialog(struct dive_site_table &imported, QString source, QWidget *parent) : QDialog(parent),
 	importedSource(source)
 {
-	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_W), this);
-	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL + Qt::Key_Q), this);
+	QShortcut *close = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_W), this);
+	QShortcut *quit = new QShortcut(QKeySequence(Qt::CTRL | Qt::Key_Q), this);
 
 	divesiteImportedModel = new DivesiteImportedModel(this);
 
