@@ -4,6 +4,7 @@
 #include "core/qthelper.h"
 #include "core/divelist.h"
 #include "core/settings/qPrefDiveComputer.h"
+#include "core/subsurface-float.h"
 #include "core/subsurface-string.h"
 #include "core/uemis.h"
 #include "core/downloadfromdcthread.h"
@@ -169,8 +170,6 @@ void DownloadFromDCWidget::DC##num##Clicked() \
 }
 #endif
 
-
-
 DCBUTTON(1)
 DCBUTTON(2)
 DCBUTTON(3)
@@ -183,7 +182,7 @@ void DownloadFromDCWidget::updateProgressBar()
 	if (empty_string(last_text)) {
 		// if we get the first actual text after the download is finished
 		// (which happens for example on the OSTC), then don't bother
-		if (!empty_string(progress_bar_text) && IS_FP_SAME(progress_bar_fraction, 1.0))
+		if (!empty_string(progress_bar_text) && nearly_equal(progress_bar_fraction, 1.0))
 			progress_bar_text = "";
 	}
 	if (!empty_string(progress_bar_text)) {
@@ -195,7 +194,7 @@ void DownloadFromDCWidget::updateProgressBar()
 		ui.progressText->setText(progress_bar_text);
 #endif
 	} else {
-		if (IS_FP_SAME(progress_bar_fraction, 0.0)) {
+		if (nearly_0(progress_bar_fraction)) {
 			// while we are waiting to connect, set the maximum to 0 so we get a busy indication
 			ui.progressBar->setMaximum(0);
 			ui.progressBar->setFormat(tr("Connecting to dive computer"));
