@@ -37,7 +37,7 @@ LocationInformationWidget::LocationInformationWidget(QWidget *parent) : QGroupBo
 	ui.diveSiteMessage->setText(tr("Dive site management"));
 	ui.diveSiteMessage->addAction(acceptAction);
 
-	connect(ui.geoCodeButton, SIGNAL(clicked()), this, SLOT(reverseGeocode()));
+	connect(ui.geoCodeButton, &QPushButton::clicked, this, &LocationInformationWidget::reverseGeocode);
 	ui.diveSiteCoordinates->installEventFilter(this);
 
 	connect(&diveListNotifier, &DiveListNotifier::diveSiteChanged, this, &LocationInformationWidget::diveSiteChanged);
@@ -57,9 +57,8 @@ void LocationInformationWidget::keyPressEvent(QKeyEvent *e)
 	return QGroupBox::keyPressEvent(e);
 }
 
-bool LocationInformationWidget::eventFilter(QObject *object, QEvent *ev)
+bool LocationInformationWidget::eventFilter(QObject *, QEvent *ev)
 {
-	Q_UNUSED(object)
 	if (ev->type() == QEvent::ContextMenu) {
 		QContextMenuEvent *ctx = (QContextMenuEvent *)ev;
 		QMenu contextMenu;
@@ -221,7 +220,7 @@ void LocationInformationWidget::acceptChanges()
 
 	MainWindow::instance()->diveList->setEnabled(true);
 	MainWindow::instance()->setEnabledToolbar(true);
-	MainWindow::instance()->setApplicationState(MainWindow::ApplicationState::Default);
+	MainWindow::instance()->enterPreviousState();
 	DiveFilter::instance()->stopFilterDiveSites();
 
 	// Subtlety alert: diveSite must be cleared *after* exiting the dive-site mode.
@@ -247,7 +246,6 @@ void LocationInformationWidget::initFields(dive_site *ds)
 	}
 }
 
-
 void LocationInformationWidget::on_GPSbutton_clicked()
 {
 	QFileInfo finfo(system_default_directory());
@@ -422,6 +420,16 @@ int DiveLocationModel::rowCount(const QModelIndex&) const
 	return dive_site_table.nr + 2;
 }
 
+Qt::ItemFlags DiveLocationModel::flags(const QModelIndex &index) const
+{
+	// This is crazy: If an entry is not marked as editable, the QListView
+	// (or rather the QAbstractItemView base class) clears the WA_InputMethod
+	// flag, which means that key-composition events are disabled. This
+	// breaks composition as long as the popup is openen. Therefore,
+	// make all items editable.
+	return QAbstractItemModel::flags(index) | Qt::ItemIsEditable;
+}
+
 bool DiveLocationModel::setData(const QModelIndex &index, const QVariant &value, int)
 {
 	if (!index.isValid())
@@ -436,9 +444,9 @@ bool DiveLocationModel::setData(const QModelIndex &index, const QVariant &value,
 }
 
 DiveLocationLineEdit::DiveLocationLineEdit(QWidget *parent) : QLineEdit(parent),
-							      proxy(new DiveLocationFilterProxyModel()),
-							      model(new DiveLocationModel()),
-							      view(new DiveLocationListView()),
+							      proxy(new DiveLocationFilterProxyModel),
+							      model(new DiveLocationModel),
+							      view(new DiveLocationListView),
 							      currDs(nullptr)
 {
 	proxy->setSourceModel(model);
@@ -496,9 +504,8 @@ bool DiveLocationLineEdit::eventFilter(QObject *, QEvent *e)
 			view->hide();
 			return true;
 		}
-	}
-	else if (e->type() == QEvent::InputMethod) {
-		this->inputMethodEvent(static_cast<QInputMethodEvent *>(e));
+	} else if (e->type() == QEvent::InputMethod) {
+		inputMethodEvent(static_cast<QInputMethodEvent *>(e));
 	}
 
 	return false;
@@ -566,8 +573,13 @@ void DiveLocationLineEdit::setTemporaryDiveSiteName(const QString &name)
 	model->setData(i1, i1_name);
 	proxy->setFilter(name);
 	fixPopupPosition();
-	if (!view->isVisible())
+	if (!view->isVisible()) {
 		view->show();
+		// TODO: For some reason the show() call clears this flag,
+		// which breaks key composition. Find the real cause for
+		// this strange behavior!
+		view->setAttribute(Qt::WA_InputMethodEnabled);
+	}
 }
 
 void DiveLocationLineEdit::keyPressEvent(QKeyEvent *ev)
@@ -672,7 +684,7 @@ struct dive_site *DiveLocationLineEdit::currDiveSite() const
 	return text().trimmed().isEmpty() ? nullptr : currDs;
 }
 
-DiveLocationListView::DiveLocationListView(QWidget*)
+DiveLocationListView::DiveLocationListView(QWidget *parent) : QListView(parent)
 {
 }
 
