@@ -32,6 +32,8 @@ void PreferencesDefaults::refreshSettings()
 		ui->grid3MBased->setChecked(true);
 	else
 		ui->gridGeneric->setChecked(true);
+
+	ui->checkBox_map_short_names->setChecked(qPrefDisplay::map_short_names());
 }
 
 void PreferencesDefaults::syncSettings()
@@ -40,4 +42,5 @@ void PreferencesDefaults::syncSettings()
 	qPrefDisplay::set_font_size(ui->fontsize->value());
 	qPrefDisplay::set_animation_speed(ui->velocitySlider->value());
 	qPrefDisplay::set_three_m_based_grid(ui->grid3MBased->isChecked());
+	qPrefDisplay::set_map_short_names(ui->checkBox_map_short_names->isChecked());
 }
