@@ -58,7 +58,6 @@
 #include <QtAndroid>
 #include "core/serial_usb_android.h"
 std::vector<android_usb_serial_device_descriptor> androidSerialDevices;
-
 #endif
 
 QMLManager *QMLManager::m_instance = NULL;
@@ -498,15 +497,24 @@ bool QMLManager::createSupportEmail()
 	if (activity.isValid()) {
 		QAndroidJniObject applogfilepath = QAndroidJniObject::fromString(appLogFileName);
 		QAndroidJniObject libdcfilepath = QAndroidJniObject::fromString(logfile_name);
-		bool success = activity.callMethod<jboolean>("shareFiles",
+		bool success = activity.callMethod<jboolean>("supportEmail",
 					"(Ljava/lang/String;Ljava/lang/String;)Z", // two string arguments, return bool
 					applogfilepath.object<jstring>(), libdcfilepath.object<jstring>());
-		qDebug() << __FUNCTION__ << "shareFiles" << (success ? "succeeded" : "failed");
+		qDebug() << __FUNCTION__ << "supportEmail" << (success ? "succeeded" : "failed");
 		if (success)
 			return true;
 	}
 	qDebug() << __FUNCTION__ << "failed to share the logFiles via intent, use the fall-back mail body method";
+#elif defined(Q_OS_IOS)
+	// call into objC++ code to share on iOS
+	QString libdcLogFileName(logfile_name);
+	iosshare.supportEmail(appLogFileName, libdcLogFileName);
+	// Unfortunately I haven't been able to figure out how to wait until the mail was sent
+	// so that this could tell us whether this was successful or not
+	// We always assume it worked and return to the caller.
+	return true;
 #endif
+	// fallback code that tries to copy the logs into the message body and uses the Qt send email method
 	QString mailToLink = "mailto:in-app-support@subsurface-divelog.org?subject=Subsurface-mobile support request";
 	mailToLink += "&body=";
 	mailToLink += messageBody;
@@ -725,6 +733,42 @@ bool QMLManager::verifyCredentials(QString email, QString password, QString pin)
 	return true;
 }
 
+void QMLManager::deleteAccount()
+{
+	QString email(prefs.cloud_storage_email);
+	QString passwd(prefs.cloud_storage_password);
+	if (email.isEmpty() || passwd.isEmpty())
+		return;
+
+	setStartPageText(tr("Deleting cloud account..."));
+	appendTextToLog(QStringLiteral("user requested that we delete cloud account for email %1").arg(email));
+	CloudStorageAuthenticate *csa = new CloudStorageAuthenticate(this);
+	csa->deleteAccount(email, passwd);
+	// let's wait here for the signal to avoid too many more nested functions
+	QTimer myTimer;
+	myTimer.setSingleShot(true);
+	QEventLoop loop;
+	connect(csa, &CloudStorageAuthenticate::finishedDelete, &loop, &QEventLoop::quit);
+	connect(&myTimer, &QTimer::timeout, &loop, &QEventLoop::quit);
+	myTimer.start(prefs.cloud_timeout * 3 * 1000); // give it extra time
+	loop.exec();
+	if (!myTimer.isActive()) {
+		// got no response from the server
+		setStartPageText(RED_FONT + tr("No response from cloud server to delete account") + END_FONT);
+		appendTextToLog(QStringLiteral("no response from cloud server to delete account"));
+		return;
+	}
+	myTimer.stop();
+	appendTextToLog(QStringLiteral("deleted the account"));
+	qPrefCloudStorage::set_cloud_storage_email("");
+	qPrefCloudStorage::set_cloud_storage_email_encoded("");
+	qPrefCloudStorage::set_cloud_storage_password("");
+	qPrefCloudStorage::set_cloud_verification_status(qPrefCloudStorage::CS_NOCLOUD);
+	set_filename(qPrintable(nocloud_localstorage()));
+	setStartPageText(tr("Cloud storage account deleted."));
+	return;
+}
+
 void QMLManager::loadDivesWithValidCredentials()
 {
 	QString url;
@@ -2167,9 +2211,6 @@ void QMLManager::exportToFile(export_types type, QString dir, bool anonymize)
 				save_dive_sites_logic(qPrintable(fileName + ".xml"), sites.data(), (int)sites.size(), anonymize);
 				break;
 			}
-		case EX_UDDF:
-			exportUsingStyleSheet(fileName + ".uddf", true, 0, "uddf-export.xslt", anonymize);
-			break;
 		default:
 			qDebug() << "export to unknown type " << type << " using " << dir << " remove names " << anonymize;
 			break;
@@ -2193,6 +2234,63 @@ void QMLManager::exportToWEB(export_types type, QString userId, QString password
 	}
 }
 
+void QMLManager::shareViaEmail(export_types type, bool anonymize)
+{
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
+	QString fileName = appLogFileName;
+#else
+	QString fileName = system_default_directory();
+#endif
+	QString body;
+	switch (type) {
+	case EX_DIVES_XML:
+		fileName.replace("subsurface.log", "subsurface.ssrf");
+		if (save_dives_logic(qPrintable(fileName), false, anonymize) == 0) {
+			// ok, we have a file, let's send it
+			body = "Subsurface dive log data";
+		} else {
+			appendTextToLog("failure to save dive log, aborting attempt to send via email");
+		}
+		break;
+	case EX_DIVE_SITES_XML:
+		fileName.replace("subsurface.log", "subsurface_divesites.xml");
+		{ // need a block so the compiler doesn't complain about creating the sites variable here
+			std::vector<const dive_site *> sites = getDiveSitesToExport(false);
+			if (save_dive_sites_logic(qPrintable(fileName), sites.data(), (int)sites.size(), anonymize) == 0) {
+				// ok, we have a file, let's send it
+				body = "Subsurface dive site data";
+			} else {
+				appendTextToLog("failure to save dive site data, aborting attempt to send via email");
+			}
+		}
+		break;
+	default:
+		qDebug() << "cannot export type " << type << " via email";
+		return;
+	}
+#if defined(Q_OS_ANDROID)
+	// let's use our nifty Java shareViaEmail function
+	QAndroidJniObject activity = QtAndroid::androidActivity();
+	if (activity.isValid()) {
+		QAndroidJniObject attachmentPath = QAndroidJniObject::fromString(fileName);
+		QAndroidJniObject subject = QAndroidJniObject::fromString("Subsurface export");
+		QAndroidJniObject bodyString = QAndroidJniObject::fromString(body);
+		QAndroidJniObject emptyString = QAndroidJniObject::fromString("");
+		bool success = activity.callMethod<jboolean>("shareViaEmail",
+					"(Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)Z", // five string arguments, return bool
+					subject.object<jstring>(), emptyString.object<jstring>(), bodyString.object<jstring>(),
+							     attachmentPath.object<jstring>(), emptyString.object<jstring>());
+		qDebug() << __FUNCTION__ << "shareViaEmail" << (success ? "succeeded" : "failed");
+	}
+#elif defined(Q_OS_IOS)
+	// call into objC++ code to share on iOS
+	QString subject("Subsurface export");
+	QString emptyString("");
+	iosshare.shareViaEmail(subject, emptyString, body, fileName, emptyString);
+#else
+	appendTextToLog("on a mobile platform this would send" + fileName + "via email with body" + body);
+#endif
+}
 void QMLManager::uploadFinishSlot(bool success, const QString &text, const QByteArray &html)
 {
 	emit uploadFinish(success, text);
@@ -2264,7 +2362,7 @@ void QMLManager::importCacheRepo(QString repo)
 QStringList QMLManager::cloudCacheList() const
 {
 	QDir localCacheDir(QString("%1/cloudstorage/").arg(system_default_directory()));
-	QStringList dirs = localCacheDir.entryList(QDir::NoDotAndDotDot);
+	QStringList dirs = localCacheDir.entryList();
 	QStringList result;
 	foreach(QString dir, dirs) {
 		QString originsDir = QString("%1/cloudstorage/%2/.git/refs/remotes/origin/").arg(system_default_directory()).arg(dir);
