@@ -19,6 +19,8 @@
 
 #if defined(Q_OS_ANDROID)
 #include "core/serial_usb_android.h"
+#elif defined(Q_OS_IOS)
+#include "ios/ios-share.h"
 #endif
 
 class QAction;
@@ -64,7 +66,6 @@ public:
 	enum export_types {
 		EX_DIVES_XML,
 		EX_DIVE_SITES_XML,
-		EX_UDDF,
 		EX_DIVELOGS_DE,
 		EX_DIVESHARE
 	};
@@ -73,7 +74,7 @@ public:
 	Q_INVOKABLE void exportToFile(export_types type, QString directory, bool anonymize);
 #endif
 	Q_INVOKABLE void exportToWEB(export_types type, QString userId, QString password, bool anonymize);
-
+	Q_INVOKABLE void shareViaEmail(export_types type, bool anonymize);
 
 	QString DC_vendor() const;
 	void DC_setVendor(const QString& vendor);
@@ -180,6 +181,7 @@ public slots:
 	void saveChangesCloud(bool forceRemoteSync, bool fromUndo = false);
 	void selectDive(int id);
 	void deleteDive(int id);
+	void deleteAccount();
 	void toggleDiveInvalid(int id);
 	void copyDiveData(int id);
 	void pasteDiveData(int id);
@@ -265,6 +267,9 @@ private:
 	QString appLogFileName;
 	QFile appLogFile;
 	bool appLogFileOpen;
+#endif
+#if defined(Q_OS_IOS)
+	IosShare iosshare;
 #endif
 	qPrefCloudStorage::cloud_status m_oldStatus;
 
