@@ -3,7 +3,7 @@
 #include "profile-widget/divetextitem.h"
 #include "core/profile.h"
 #include "core/qthelper.h"
-#include "core/subsurface-string.h"
+#include "core/subsurface-float.h"
 #include "profile-widget/animationfunctions.h"
 #include "profile-widget/divelineitem.h"
 #include "profile-widget/profilescene.h"
@@ -436,13 +436,23 @@ double DiveCartesianAxis::valueAt(const QPointF &p) const
 	return fraction * (max - min) + min;
 }
 
+double DiveCartesianAxis::deltaToValue(double delta) const
+{
+	QLineF m = line();
+	double screenSize = position == Position::Bottom ? m.x2() - m.x1()
+							 : m.y2() - m.y1();
+	double axisSize = max - min;
+	double res = delta * axisSize / screenSize;
+	return ((position == Position::Bottom) == inverted) ? -res : res;
+}
+
 double DiveCartesianAxis::posAtValue(double value, double max, double min) const
 {
 	QLineF m = line();
 
 	double screenFrom = position == Position::Bottom ? m.x1() : m.y1();
 	double screenTo = position == Position::Bottom ? m.x2() : m.y2();
-	if (IS_FP_SAME(min, max))
+	if (nearly_equal(min, max))
 		return (screenFrom + screenTo) / 2.0;
 	if ((position == Position::Bottom) == inverted)
 		std::swap(screenFrom, screenTo);
