@@ -45,7 +45,7 @@ slots:
 	void setRect(const QRectF &rect);
 
 private:
-	typedef QPair<QGraphicsPixmapItem *, QGraphicsSimpleTextItem *> ToolTip;
+	typedef QPair<QGraphicsPixmapItem *, QGraphicsTextItem *> ToolTip;
 	QVector<ToolTip> toolTips;
 	ToolTip entryToolTip;
 	QGraphicsSimpleTextItem *title;
