@@ -9,7 +9,7 @@
 static const double gridWidth = 1.0;
 
 StatsGrid::StatsGrid(StatsView &view, const StatsAxis &xAxis, const StatsAxis &yAxis)
-	: view(view), xAxis(xAxis), yAxis(yAxis)
+	: view(view), theme(view.getCurrentTheme()), xAxis(xAxis), yAxis(yAxis)
 {
 }
 
@@ -28,11 +28,11 @@ void StatsGrid::updatePositions()
 		return;
 
 	for (double x: xtics) {
-		lines.push_back(view.createChartItem<ChartLineItem>(ChartZValue::Grid, gridColor, gridWidth));
+		lines.push_back(view.createChartItem<ChartLineItem>(ChartZValue::Grid, theme.gridColor, gridWidth));
 		lines.back()->setLine(QPointF(x, ytics.front()), QPointF(x, ytics.back()));
 	}
 	for (double y: ytics) {
-		lines.push_back(view.createChartItem<ChartLineItem>(ChartZValue::Grid, gridColor, gridWidth));
+		lines.push_back(view.createChartItem<ChartLineItem>(ChartZValue::Grid, theme.gridColor, gridWidth));
 		lines.back()->setLine(QPointF(xtics.front(), y), QPointF(xtics.back(), y));
 	}
 }
