@@ -6,7 +6,6 @@
 #include "statshelper.h"
 #include "statsselection.h"
 #include <memory>
-#include <QFont>
 #include <QImage>
 #include <QPainter>
 #include <QQuickItem>
@@ -29,6 +28,7 @@ class QuartileMarker;
 class RegressionItem;
 class StatsAxis;
 class StatsGrid;
+class StatsTheme;
 class Legend;
 class QSGTexture;
 class RootNode;	// Internal implementation detail
@@ -53,6 +53,8 @@ public:
 	QQuickWindow *w() const;			// Make window available to items
 	QSizeF size() const;
 	QRectF plotArea() const;
+	void setTheme(bool dark);			// Chart must be replot for theme to become effective.
+	const StatsTheme &getCurrentTheme() const;
 	void addQSGNode(QSGNode *node, ChartZValue z);	// Must only be called in render thread!
 	void registerChartItem(ChartItem &item);
 	void registerDirtyChartItem(ChartItem &item);
@@ -77,7 +79,11 @@ private:
 	QRectF plotRect;
 	QSGNode *updatePaintNode(QSGNode *oldNode, QQuickItem::UpdatePaintNodeData *updatePaintNodeData) override;
 
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	void geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#else
 	void geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry) override;
+#endif
 	void plotAreaChanged(const QSizeF &size);
 	void reset(); // clears all series and axes
 	void setAxes(StatsAxis *x, StatsAxis *y);
@@ -136,7 +142,7 @@ private:
 	void addLineMarker(double pos, double low, double high, const QPen &pen, bool isHorizontal);
 
 	StatsState state;
-	QFont titleFont;
+	const StatsTheme *currentTheme;
 	std::vector<std::unique_ptr<StatsSeries>> series;
 	std::unique_ptr<StatsGrid> grid;
 	std::vector<ChartItemPtr<QuartileMarker>> quartileMarkers;
